# psat-server-web
Python 3 web interface for the Pan-STARRS and ATLAS surveys.

To install:

pip install psat-server-web

Once installed, don't forget to add the "data" symlinks in the:

site-packages/psat\_server\_web/atlas/media/images
site-packages/psat\_server\_web/ps1/media/images

directories which point to the location of the image stamps.
